==> mmoo_base_recharge-1.2.3.tar.gz: lib/card/utils/recharge_constant.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

///颜色
class RechargeConstantColors {
  static const Color app_color = Color(0xFFA571FF);
  static const Color line_color = Color(0xFFDDDDDD);
  static const Color card_line_color = Color(0xFFF0F0F0);
  static const Color bg_pop_color = Color(0xFF1F1A33);
  static const Color color_blue = Color(0xFF565FD6);
  static const Color text_tip2_color = Color(0xFF666666);
  static const Color text_black_color = Color(0xFF222222);
  static const Color text_tip_color = Color(0xFF999999);
  static const Color red_color = Color(0xFFFF4589);
  static const Color color_btn_un = Color(0xFF362056);
  static const Color color_white60 = Color(0xFF60FFFFFF);
}

///文本样式
class RechargeConstantText {
  static double setSp(num fontSize) => fontSize * ScreenUtil().scaleWidth;

  static const text20 = 20.0;
  static const text18 = 18.0;
  static const text16 = 16.0;
  static const text14 = 14.0;
  static const text12 = 12.0;

  static final text14Blue = TextStyle(
      color: RechargeConstantColors.color_blue,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14Hint2 = TextStyle(
      color: RechargeConstantColors.text_tip2_color,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text20BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text20),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text20HintBold = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text20),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text12Red = TextStyle(
      color: RechargeConstantColors.red_color,
      fontSize: setSp(text12),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16Hint = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16HintBold = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text20WhiteBold = TextStyle(
      color: Colors.white,
      fontSize: setSp(text20),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14White = TextStyle(
      color: Colors.white,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16WhiteBold = TextStyle(
      color: Colors.white,
      fontSize: setSp(text16),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16Black = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text18BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text18),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16Hint2 = TextStyle(
      color: RechargeConstantColors.text_tip2_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text18BlueBold = TextStyle(
      color: RechargeConstantColors.color_blue,
      fontSize: setSp(text18),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text14),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14Black = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text12Hint = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text12),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14WhiteBold = TextStyle(
      color: Colors.white,
      fontSize: setSp(text14),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16White = TextStyle(
      color: Colors.white,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14White60Bold = TextStyle(
      color: RechargeConstantColors.color_white60,
      fontSize: setSp(text14),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
}

///图标
class RechargeConstantIcons {
  static const String images = 'images/';

  static const String app_return = images + 'app_return.png';
  static const String app_pop_close = images + 'app_pop_close.png';
  static const String pop_selected = images + 'pop_selected.png';
  static const String pop_unselected = images + 'pop_unselected.png';
  static const String pop_success = images + 'pop_success.png';

  static const String card_americon = images + 'card_americon.png';
  static const String card_card = images + 'card_card.png';
  static const String card_close = images + 'card_close.png';
  static const String card_dinersclub = images + 'card_dinersclub.png';
  static const String card_discover = images + 'card_discover.png';
  static const String card_down = images + 'card_down.png';
  static const String card_mastercard = images + 'card_mastercard.png';
  static const String card_right = images + 'card_right.png';
  static const String card_tip = images + 'card_tip.png';
  static const String card_VISA = images + 'card_VISA.png';
  static const String card_address = images + 'card_address.png';
  static const String card_error = images + 'card_error.png';
  static const String card_CVV3 = images + 'card_cvv3.png';
  static const String card_CVV4 = images + 'card_cvv4.png';
}

==> mmoo_base_recharge-2.0.0.tar.gz: lib/card/utils/recharge_constant.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

///颜色
class RechargeConstantColors {
  static const Color app_color = Color(0xFFA571FF);
  static const Color line_color = Color(0xFFDDDDDD);
  static const Color card_line_color = Color(0xFFF0F0F0);
  static const Color bg_pop_color = Color(0xFF1F1A33);
  static const Color color_blue = Color(0xFF565FD6);
  static const Color text_tip2_color = Color(0xFF666666);
  static const Color text_black_color = Color(0xFF222222);
  static const Color text_tip_color = Color(0xFF999999);
  static const Color red_color = Color(0xFFFF4589);
  static const Color color_btn_un = Color(0xFF362056);
  static const Color color_white60 = Color(0xFF60FFFFFF);
}

///文本样式
class RechargeConstantText {
  static double setSp(num fontSize) => fontSize * ScreenUtil().scaleWidth;

  static const text20 = 20.0;
  static const text18 = 18.0;
  static const text16 = 16.0;
  static const text14 = 14.0;
  static const text12 = 12.0;

  static final text14Blue = TextStyle(
      color: RechargeConstantColors.color_blue,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14Hint2 = TextStyle(
      color: RechargeConstantColors.text_tip2_color,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text20BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text20),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text20HintBold = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text20),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text12Red = TextStyle(
      color: RechargeConstantColors.red_color,
      fontSize: setSp(text12),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16Hint = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16HintBold = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text20WhiteBold = TextStyle(
      color: Colors.white,
      fontSize: setSp(text20),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14White = TextStyle(
      color: Colors.white,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16WhiteBold = TextStyle(
      color: Colors.white,
      fontSize: setSp(text16),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16Black = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text18BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text18),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16Hint2 = TextStyle(
      color: RechargeConstantColors.text_tip2_color,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text18BlueBold = TextStyle(
      color: RechargeConstantColors.color_blue,
      fontSize: setSp(text18),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14BlackBold = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text14),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14Black = TextStyle(
      color: RechargeConstantColors.text_black_color,
      fontSize: setSp(text14),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text12Hint = TextStyle(
      color: RechargeConstantColors.text_tip_color,
      fontSize: setSp(text12),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14WhiteBold = TextStyle(
      color: Colors.white,
      fontSize: setSp(text14),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text16White = TextStyle(
      color: Colors.white,
      fontSize: setSp(text16),
      fontWeight: FontWeight.w500,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
  static final text14White60Bold = TextStyle(
      color: RechargeConstantColors.color_white60,
      fontSize: setSp(text14),
      fontWeight: FontWeight.bold,
      fontFamily: 'Rounded',
      decoration: TextDecoration.none);
}

///图标
class RechargeConstantIcons {
  static const String imagesUrl = 'http://file.vvlive.fun/runnowi16/card/';

  static const String app_return = imagesUrl + 'app_return.png';
  static const String app_pop_close = imagesUrl + 'app_pop_close.png';
  static const String pop_selected = imagesUrl + 'pop_selected.png';
  static const String pop_unselected = imagesUrl + 'pop_unselected.png';
  static const String pop_success = imagesUrl + 'pop_success.png';

  static const String card_americon = imagesUrl + 'card_americon.png';
  static const String card_card = imagesUrl + 'card_card.png';
  static const String card_close = imagesUrl + 'card_close.png';
  static const String card_dinersclub = imagesUrl + 'card_dinersclub.png';
  static const String card_discover = imagesUrl + 'card_discover.png';
  static const String card_down = imagesUrl + 'card_down.png';
  static const String card_mastercard = imagesUrl + 'card_mastercard.png';
  static const String card_right = imagesUrl + 'card_right.png';
  static const String card_tip = imagesUrl + 'card_tip.png';
  static const String card_VISA = imagesUrl + 'card_VISA.png';
  static const String card_address = imagesUrl + 'card_address.png';
  static const String card_error = imagesUrl + 'card_error.png';
  static const String card_CVV3 = imagesUrl + 'card_cvv3.png';
  static const String card_CVV4 = imagesUrl + 'card_cvv4.png';
  static const String mastercard = imagesUrl + 'mastercard.png';
  static const String visacard = imagesUrl + 'visacard.png';
  static const String discover = imagesUrl + 'discover.png';
  static const String amex = imagesUrl + 'amex.png';
}
